Configuration class abstract Configuration

Configuration used to create a Realm instance

Implementers

Properties

encryptionKey → List<int>?
The key used to encrypt the entire Realm.
final
fifoFilesFallbackPath → String?
Specifies the FIFO special files fallback location.
final
hashCode → int
The hash code for this object.
no setterinherited
maxNumberOfActiveVersions → int?
Sets the maximum number of active versions allowed before an exception is thrown.
final
path ↔ String
The path where the Realm should be stored.
latefinal
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schemaObjects → Iterable<SchemaObject>
A collection of SchemaObject that will be used to construct the RealmSchema once the Realm is opened.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

defaultRealmName ↔ String
The default realm filename to be used.
getter/setter pair
defaultRealmPath ↔ String
The platform dependent path to the default realm file.
getter/setter pair
defaultStoragePath → String
The platform dependent path used to store realm files
no setter

Static Methods

inMemory(List<SchemaObject> schemaObjects, {String? fifoFilesFallbackPath, String? path, int? maxNumberOfActiveVersions}) → InMemoryConfiguration
Constructs a InMemoryConfiguration
local(List<SchemaObject> schemaObjects, {InitialDataCallback? initialDataCallback, int schemaVersion = 0, String? fifoFilesFallbackPath, String? path, List<int>? encryptionKey, bool disableFormatUpgrade = false, bool isReadOnly = false, ShouldCompactCallback? shouldCompactCallback, MigrationCallback? migrationCallback, int? maxNumberOfActiveVersions, bool shouldDeleteIfMigrationNeeded = false}) → LocalConfiguration
Constructs a LocalConfiguration