DynamicRealm class Realm

Exposes a set of dynamic methods on the Realm object. These don't use strongly typed classes and instead lookup objects by string name.

Implementers

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

all(String className) → RealmResults<RealmObject>
Returns all RealmObjects of type className in the Realm
create(String className, {Object? primaryKey}) → RealmObject
Creates a managed RealmObject with the specified className and primaryKey.
find(String className, Object primaryKey) → RealmObject?
Fast lookup for a RealmObject of type className with the specified primaryKey.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited