DynamicRealmObject class Realm

Exposes a set of dynamic methods on the RealmObject type. These allow you to access properties by name rather than via the strongly typed API.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

get<T extends Object?>(String name) → T
Gets a property by its name. If a generic type is specified, the property type will be validated against the type. Otherwise the result will be wrapped in Object.
getList<T extends Object?>(String name) → RealmList<T>
Gets a list by the property name. If a generic type is specified, the property type will be validated against the type. Otherwise, a List<Object> will be returned.
getMap<T extends Object?>(String name) → RealmMap<T>
Gets a map by the property name. If a generic type is specified, the property type will be validated against the type. Otherwise, a RealmMap<Object?> will be returned.
getSet<T extends Object?>(String name) → RealmSet<T>
Gets a set by the property name. If a generic type is specified, the property type will be validated against the type. Otherwise, a RealmSet<Object?> will be returned.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set<T extends Object?>(String name, T value) → void
Sets a property by its name. The supplied value must be assignable to the property type, otherwise an exception will be thrown.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited