InMemoryConfiguration class Configuration

InMemoryConfiguration is used to open Realm instances that are temporary to running process.

Inheritance

Properties

encryptionKey → List<int>?
The key used to encrypt the entire Realm.
finalinherited
fifoFilesFallbackPath → String?
Specifies the FIFO special files fallback location.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
maxNumberOfActiveVersions → int?
Sets the maximum number of active versions allowed before an exception is thrown.
finalinherited
path ↔ String
The path where the Realm should be stored.
latefinalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schemaObjects → Iterable<SchemaObject>
A collection of SchemaObject that will be used to construct the RealmSchema once the Realm is opened.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited