Move class

Contains index information about objects that moved within the same collection.

Constructors

Move(int from, int to)
const

Properties

from → int
The index in the old version of the collection.
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
to → int
The index in the new version of the collection.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override