RealmException class Realm

An exception being thrown when a Realm operation or RealmObject access fails.

Implemented types
Implementers

Constructors

RealmException(String message, {String? helpLink})

Properties

hashCode → int
The hash code for this object.
no setterinherited
A link to the documentation that explains how to resolve the error.
final
message → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited