RealmMapChanges<T extends Object?> class

Describes the changes in a Realm map collection since the last time the notification callback was invoked.

Properties

deleted → List<String>
The keys of the map which have been removed.
no setter
handle → MapChangesHandle
final
hashCode → int
The hash code for this object.
no setterinherited
inserted → List<String>
The keys of the map which were added.
no setter
isCleared → bool
true if the map was cleared.
no setter
isCollectionDeleted → bool
true if the underlying map was deleted.
no setter
map → RealmMap<T>
The collection being monitored for changes.
final
modified → List<String>
The keys of the map, whose corresponding values were modified in this version.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited