RealmModel class Annotations

Annotation class used to define Realm data model classes and their properties

Constructors

RealmModel([ObjectType baseType = ObjectType.realmObject])
Creates a new instance of RealmModel optionally specifying the baseType.
const
RealmModel.using({ObjectType baseType = ObjectType.realmObject, GeneratorConfig generatorConfig = const GeneratorConfig()})
Creates a new instance of RealmModel optionally specifying the baseType and generatorConfig.
const

Properties

baseType → ObjectType
The base type of the generated object class
final
generatorConfig → GeneratorConfig
The generator configuration to use for this model
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited