RealmObjectChanges<T extends RealmObjectBase> class

Describes the changes in on a single RealmObject since the last time the notification callback was invoked.

Properties

hashCode → int
The hash code for this object.
no setterinherited
isDeleted → bool
True if the object was deleted.
no setter
object → T
The realm object being monitored for changes.
final
properties → List<String>
The property names that have changed.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited