waitForUpload method
Waits for the Session to finish all pending uploads.
An optional cancellationToken can be used to cancel the wait operation.
Implementation
Future<void> waitForUpload([CancellationToken? cancellationToken]) => realmCore.sessionWaitForUpload(this, cancellationToken);